Index: sdk/lib/_internal/compiler/compiler.dart |
diff --git a/sdk/lib/_internal/compiler/compiler.dart b/sdk/lib/_internal/compiler/compiler.dart |
index bbee705a0386725a035cfbb0f97a335768543b70..4ee688775eb09c55df8009fb5e7c675146f85734 100644 |
--- a/sdk/lib/_internal/compiler/compiler.dart |
+++ b/sdk/lib/_internal/compiler/compiler.dart |
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri); |
typedef Future<String> ReadStringFromUri(Uri uri); |
/** |
* Returns a [StreamSink] that will serve as compiler output for the given |
ngeoffray
2013/03/08 10:27:12
a -> an
Lasse Reichstein Nielsen
2013/03/08 11:22:37
Done.
|
* component. |
* |
* Components are identified by [name] and [extension]. By convention, |
@@ -41,8 +41,8 @@ typedef Future<String> ReadStringFromUri(Uri uri); |
* As more features are added to the compiler, new names and |
* extensions may be introduced. |
*/ |
-typedef StreamSink<String> CompilerOutputProvider(String name, |
- String extension); |
+typedef EventSink<String> CompilerOutputProvider(String name, |
+ String extension); |
/** |
* Invoked by the compiler to report diagnostics. If [uri] is |
@@ -22,7 +22,7 @@ typedef Future<String> CompilerInputProvider(Uri uri); |
typedef Future<String> ReadStringFromUri(Uri uri); |
/** |
- * Returns a [StreamSink] that will serve as compiler output for the given |
+ * Returns a [EventSink] that will serve as compiler output for the given |
ngeoffray
2013/03/08 10:27:12